@@ -25,7 +25,7 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 from __future__ import unicode_literals
 
-__version__ = version = '0.6.0'
+__version__ = version = '0.6.1'
 
 import sys
 
@@ -38,5 +38,5 @@ activate = httprettified
 
 SELF = sys.modules[__name__]
 
-for attr in list(httpretty.METHODS) + ['register_uri', 'enable', 'disable', 'is_enabled', 'Response']:
+for attr in [name.decode() for name in httpretty.METHODS] + ['register_uri', 'enable', 'disable', 'is_enabled', 'Response']:
     setattr(SELF, attr, getattr(httpretty, attr))
