@@ -51,6 +51,7 @@ from .http import (
     STATUSES,
     HttpBaseClass,
     parse_requestline,
+    last_requestline,
 )
 
 from .utils import (
@@ -224,7 +225,6 @@ class fakesock(object):
         def sendall(self, data, *args, **kw):
 
             self._sent_data.append(data)
-            hostnames = [getattr(i.info, 'hostname', None) for i in httpretty._entries.keys()]
             self.fd.seek(0)
             try:
                 requestline, _ = data.split(b'\r\n', 1)
@@ -233,15 +233,25 @@ class fakesock(object):
             except ValueError:
                 is_parsing_headers = False
 
-                if self._host not in hostnames:
+                if not self._entry:
+                    # If the previous request wasn't mocked, don't mock the subsequent sending of data
                     return self._true_sendall(data)
 
             if not is_parsing_headers:
                 if len(self._sent_data) > 1:
-                    headers, body = map(utf8, self._sent_data[-2:])
+                    headers = utf8(last_requestline(self._sent_data))
+                    body = utf8(self._sent_data[-1])
+
+                    last_entry = self._entry
+                    last_entry.request.body = body
+                    request_headers = dict(last_entry.request.headers)
+                    # If we are receiving more data and the last entry to be processed
+                    # was a callback responsed, send the new data to the callback
+                    if last_entry.body_is_callable:
+                        last_entry.callable_body(last_entry.request, last_entry.info.full_url(), request_headers)
+
                     try:
                         return httpretty.historify_request(headers, body, False)
-
                     except Exception as e:
                         logging.error(traceback.format_exc(e))
                         return self._true_sendall(data, *args, **kw)
@@ -266,6 +276,7 @@ class fakesock(object):
                     break
 
             if not entries:
+                self._entry = None
                 self._true_sendall(data)
                 return
 
@@ -527,14 +538,14 @@ class URIInfo(BaseClass):
         )
         return self_tuple == other_tuple
 
-    def full_url(self):
+    def full_url(self, use_querystring=True):
         credentials = ""
         if self.password:
             credentials = "{0}:{1}@".format(
                 self.username, self.password)
 
         query = ""
-        if self.query:
+        if use_querystring and self.query:
             query = "?{0}".format(decode_utf8(self.query))
 
         result = "{scheme}://{credentials}{host}{path}{query}".format(
@@ -580,7 +591,7 @@ class URIMatcher(object):
         if self.info:
             return self.info == info
         else:
-            return self.regex.search(info.full_url())
+            return self.regex.search(info.full_url(use_querystring=False))
 
     def __str__(self):
         wrap = 'URLMatcher({0})'
